flutter_simple_webview library

Classes

Representation of a cookie. For cookies received by the server as Cookie header values only name and value properties will be set. When building a cookie for the 'set-cookie' header in the server and when receiving cookies in the client as 'set-cookie' headers all fields can be used.
SimpleWebViewScaffold
WebResourceError
Error returned in WebView.onWebResourceError when a web resource loading error has occurred.

Enums

WebResourceErrorType
Possible error type categorizations used by WebResourceError.

Typedefs

FlutterSimpleWebView = SimpleWebViewScaffold
Alias for SimpleWebViewScaffold to maintain package naming convention compatibility if desired, or simply serve as the main entry point.